@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Inline;
 
 our $DATE = '2015-06-16'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $VERSION = '0.07'; # VERSION
 
 use 5.010001;
 use strict;
@@ -751,7 +751,7 @@ Perinci::CmdLine::Inline - Generate inline Perinci::CmdLine CLI script
 
 =head1 VERSION
 
-This document describes version 0.06 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2015-06-16.
+This document describes version 0.07 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2015-06-16.
 
 =head1 SYNOPSIS
 
@@ -777,19 +777,23 @@ B<EARLY DEVELOPMENT.>
 
 Sample startup overhead benchmark vs Perinci::CmdLine::Lite:
 
-                               Rate    run (lite) --version (lite) run (inline) --version (inline)   perl
- run (lite)         13.697+-0.011/s            --           -60.8%       -79.1%             -81.5% -97.2%
- --version (lite)   34.979+-0.048/s  155.38+-0.4%               --       -46.7%             -52.8% -92.9%
- run (inline)        65.673+-0.09/s 379.46+-0.76%     87.75+-0.36%           --             -11.4% -86.7%
- --version (inline)   74.13+-0.12/s 441.21+-0.98%    111.93+-0.45% 12.88+-0.24%                 -- -85.0%
- perl                  493.4+-1.5/s     3502+-11%     1310.5+-4.6%  651.3+-2.5%        565.6+-2.3%     --
+                                    Rate  run 1 (lite) run --version (lite) run 1 (inline) run --version (inline)   -c (lite) -c (inline)   perl
+ run 1 (lite)           13.649+-0.0081/s            --               -61.3%         -79.2%                 -81.9%      -82.5%      -91.6% -97.6%
+ run --version (lite)    35.264+-0.055/s 158.36+-0.43%                   --         -46.2%                 -53.2%      -54.8%      -78.4% -93.8%
+ run 1 (inline)             65.6+-0.14/s     380.6+-1%         86.04+-0.48%             --                 -12.9%      -16.0%      -59.8% -88.5%
+ run --version (inline)   75.281+-0.06/s 451.55+-0.55%        113.48+-0.38%   14.75+-0.25%                     --       -3.6%      -53.8% -86.9%
+ -c (lite)                 78.08+-0.17/s   472.1+-1.3%         121.42+-0.6%   19.02+-0.36%            3.72+-0.24%          --      -52.1% -86.4%
+ -c (inline)                163.1+-1.6/s     1095+-12%          362.5+-4.7%    148.6+-2.5%            116.6+-2.2% 108.9+-2.1%          -- -71.5%
+ perl                       572.7+-3.1/s     4096+-23%         1524.2+-9.3%      773+-5.1%            660.8+-4.2% 633.5+-4.3%   251.2+-4%     --
  
  Average times:
-   perl              :     2.0268ms
-   --version (inline):    13.4898ms
-   run (inline)      :    15.2270ms
-   --version (lite)  :    28.5886ms
-   run (lite)        :    73.0087ms
+   perl                  :     1.7461ms
+   -c (inline)           :     6.1312ms
+   -c (lite)             :    12.8074ms
+   run --version (inline):    13.2836ms
+   run 1 (inline)        :    15.2439ms
+   run --version (lite)  :    28.3575ms
+   run 1 (lite)          :    73.2654ms
 
 =head1 FUNCTIONS
 
